@@ -1,8 +1,13 @@
 try:
-    from . import _lib as lib
+    from pynut_1tools.pyNutTools import _lib as lib
 except:
-    try:    import _lib as lib
-    except: from pyNutTools import _lib as lib
+    try:
+        from pyNutTools import _lib as lib
+    except:
+        try:
+            from . import _lib as lib
+        except:
+            import _lib as lib
 
 import math
 logger = lib.logger()
@@ -54,11 +59,15 @@ def fDf_applyStyle(df_in, str_style = 'GreenRed'):
     
 
 
-#-------------------------------------------
-# Compare DF (only a column)
-#-------------------------------------------
+#--------------------------------------------------------------
+# Check Dataframe are the same (identical)
+#--------------------------------------------------------------
+def fBl_DfAreEquals(df1, df2):
+    return df1.equals(df2)
+
 def fBl_compareDfCol(d_1, d_2, str_how = 'inner'):
-    """ compare 2 dataframe one a numeric column by joining the df and returning the difference """
+    """ compare 2 dataframe (only a column)
+    one a numeric column by joining the df and returning the difference """
     # Param
     df1 =           d_1['df']
     str_colJoin1 =  d_1['colJoin']
